##  Related Resources
To view examples for calculating the application total cost of ownership, refer to [Advanced Cost Management with Customized Configurations](https://help.sap.com/docs/leanix/ea/cost-management?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759840a7a441014b9b08e71b843f53b__Advanced-Cost-Management-with-Customized-Configurations)
